 
<?php
/**
 * Lotto
 *
 * @package mod_lotto
 * @author Marc Oliveras <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2017 Oligalma
 * @license GPL License v3
 */
 
// No direct access
defined('_JEXEC') or die;

$document = JFactory::getDocument();
$document->addStyleDeclaration('
	#get-numbers-button {
		font-weight:bold;
		font-size:22px;
		padding:10px;
		background:' . $buttonBgColor . ';
		color:' . $buttonTextColor .';
	}
	
	#numbers-display {
		margin-top:20px;
	}
	
	.lotto-ball
	{
		border:1px solid black;
		border-radius:50%;
		background:radial-gradient(' . $ballBg1Color . ',' . $ballBg2Color . ');
		font-size:17px;
		font-weight:bold;
		color:' . $ballTextColor . ';
		width:20px;
		height:20px;
		margin-right:5px;
		margin-bottom:5px;
		float:left;
		padding:5px;
	}
	
	.power-ball
	{
        background:radial-gradient(' . $powerballBg1Color . ', ' . $powerballBg2Color . ');
        color:' . $powerballTextColor . ';
	}
	
	.hidden-ball, .hidden-combination
	{
		display:none;
	}
	
	.clear
	{
		clear:both;
	}
');
$document->addScriptDeclaration('
	jQuery(document).ready(function($){
		var maxNumber = ' . $maxNumber .';
		var ballsNumber = ' . $ballsNumber . ';
		var maxPowerballNumber = ' . $maxPowerballNumber . ';
		var enableAnimation = ' . $enableAnimation . ';
		var delay = ' . $ballsDelay . ';
		var enableSound = ' . $enableSound . ';
		
		$("#get-numbers-button").click(function(){
			$("#numbers-display").html("");
			
			if(enableSound)
				playSound();
					
			for(z = 1; z <= $("#combinations").val(); z++)
			{
				var numbers = [];
				for (i = 0; i < ballsNumber; i++) {
					var number = Math.floor(Math.random() * maxNumber) + 1;
					var found = false;
					for(j = 0; j < numbers.length; j++)
					{
						if(numbers[j] == number)
							found = true;
					}
					if(!found)
						numbers.push(number);
					else
						i--;
				}

				numbers.sort(function sortNumber(a,b){
					return a - b;
				});
				
                var powerBall = Math.floor(Math.random() * maxPowerballNumber) + 1;
				
				if(enableAnimation)
				{
					$("#numbers-display").append(\'<b class="hidden-combination" id="combination\' + z + \'">\' + z + \'</b>\');
					
					$.each(numbers, function (index, value) {
						$("#numbers-display").append(\'<div class="lotto-ball hidden-ball">\' + value + \'</div>\');
					});
					
					if(maxPowerballNumber)
                        $("#numbers-display").append(\'<div class="lotto-ball power-ball hidden-ball">\' + powerBall + \'</div>\');
                        
					$(".hidden-ball").each(function (index, value) {
						$(this).delay(delay * index).fadeIn();
					});
					
					$("#combination" + z).delay(delay * ballsNumber * z).fadeIn();
				}
				else
				{	
					$("#numbers-display").append(\'<b>\' + z + \'</b>\');
					
					$.each(numbers, function (index, value) {
						$("#numbers-display").append(\'<div class="lotto-ball">\' + value + \'</div>\');
					});
					
					if(maxPowerballNumber)
                        $("#numbers-display").append(\'<div class="lotto-ball power-ball">\' + powerBall + \'</div>\');
				}
				
				$("#numbers-display").append(\'<div class="clear"></div>\');
			}
		});
		
		function playSound()
		{
			var balls_audio = document.createElement("audio");
			balls_audio.setAttribute("src", "' . JURI::base() . 'modules/mod_lotto/magic.mp3");
			balls_audio.play();		
		}
	});
');
?>
<input id="get-numbers-button" type="button" value="<?= JText::_('MOD_LOTTO_GET_NUMBERS') ?>" />
&nbsp;&nbsp;<b>Combinations:</b>&nbsp;<input id="combinations" type="text" value="5" size="2" />
<div id="numbers-display"></div>
